/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * TimeStepPresentValidator.cpp
 *
 *  Created on: May 10, 2012
 *      Author: ankele
 */


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "TimeStepPresentValidator.hpp"

#include "WorldTime.hpp"
#include "World.hpp"

bool TimeStepPresentValidator::isValid(const unsigned int & _value) const
{
  size_t maxTime = 0;
  std::vector<const atom*> AllAtoms = const_cast<const World &>(World::getInstance()).
      getAllAtoms();
  for(std::vector<const atom*>::const_iterator AtomRunner = AllAtoms.begin();
      AtomRunner != AllAtoms.end(); ++AtomRunner) {
    size_t sizeTrajectory = (dynamic_cast<const AtomInfo *>(*AtomRunner))->getTrajectorySize();
    if (sizeTrajectory > maxTime)
      maxTime = sizeTrajectory;
  }

  return (_value <= maxTime);
}

bool TimeStepPresentValidator::operator==(const Validator<unsigned int> &_instance) const
{
  const TimeStepPresentValidator *inst =
      dynamic_cast<const TimeStepPresentValidator *>(&_instance);
  if (inst)
    return true;
  else
    return false;
}

Validator< unsigned int >* TimeStepPresentValidator::clone() const
{
  Validator< unsigned int > *inst =
      new TimeStepPresentValidator();
  return inst;
}




